==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebTreeDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebTreeDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebTreeDescription, _super);
    function WebTreeDescription() {
        var _this = _super.call(this) || this;
        _this.f = false;
        _this.n = null;
        _this.i = null;
        _this.p = null;
        _this.o = null;
        _this.m = null;
        _this.l = null;
        _this.k = null;
        _this.j = null;
        _this.h = null;
        return _this;
    }
    WebTreeDescription.prototype.get_type = function () {
        return "WebTree";
    };
    Object.defineProperty(WebTreeDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "singleBranchExpand", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("SingleBranchExpand");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "selection", {
        get: function () {
            return this.n;
        },
        set: function (a) {
            this.n = a;
            this.e("Selection");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "dir", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.e("Dir");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "size", {
        get: function () {
            return this.p;
        },
        set: function (a) {
            this.p = a;
            this.e("Size");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "selectionChangedRef", {
        get: function () {
            return this.o;
        },
        set: function (a) {
            this.o = a;
            this.e("SelectionChangedRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "itemExpandingRef", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.e("ItemExpandingRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "itemExpandedRef", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.e("ItemExpandedRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "itemCollapsingRef", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.e("ItemCollapsingRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "itemCollapsedRef", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.e("ItemCollapsedRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "activeItemRef", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("ActiveItemRef");
        },
        enumerable: true,
        configurable: true
    });
    WebTreeDescription.$t = markType(WebTreeDescription, 'WebTreeDescription', Description.$);
    return WebTreeDescription;
}(Description));
export { WebTreeDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebTreeDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebTreeDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTreeDescription, _super);
    function WebTreeDescription() {
        var _this = _super.call(this) || this;
        _this.h = false;
        _this.i = false;
        _this.q = null;
        _this.r = null;
        _this.p = null;
        _this.o = null;
        _this.n = null;
        _this.m = null;
        _this.l = null;
        return _this;
    }
    WebTreeDescription.prototype.get_type = function () {
        return "WebTree";
    };
    Object.defineProperty(WebTreeDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "singleBranchExpand", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("SingleBranchExpand");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "toggleNodeOnClick", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("ToggleNodeOnClick");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "selection", {
        get: function () {
            return this.q;
        },
        set: function (a) {
            this.q = a;
            this.g("Selection");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "selectionChangedRef", {
        get: function () {
            return this.r;
        },
        set: function (a) {
            this.r = a;
            this.g("SelectionChangedRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "itemExpandingRef", {
        get: function () {
            return this.p;
        },
        set: function (a) {
            this.p = a;
            this.g("ItemExpandingRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "itemExpandedRef", {
        get: function () {
            return this.o;
        },
        set: function (a) {
            this.o = a;
            this.g("ItemExpandedRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "itemCollapsingRef", {
        get: function () {
            return this.n;
        },
        set: function (a) {
            this.n = a;
            this.g("ItemCollapsingRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "itemCollapsedRef", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.g("ItemCollapsedRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTreeDescription.prototype, "activeItemRef", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.g("ActiveItemRef");
        },
        enumerable: false,
        configurable: true
    });
    WebTreeDescription.$t = markType(WebTreeDescription, 'WebTreeDescription', Description.$);
    return WebTreeDescription;
}(Description));
export { WebTreeDescription };
